@@ -2,7 +2,7 @@ package App::Greple::under::line;
 use strict;
 use warnings;
 
-our $VERSION = "0.9903";
+our $VERSION = "0.9904";
 
 use App::Greple::under ':all';
 
@@ -12,5 +12,5 @@ __DATA__
 
 option default \
     -Munder \
-    --under-custom-colormap \
-    --under-line
+    --use-custom-colormap \
+    --place-line
